/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/

/*! \file ComboBoxModel.cpp
    \brief Contains data for ComboBox QML component

    \author Marcin Kaźmierczak <marcin.kazmierczak@comarch.pl>
*/

#include "ComboBoxModel.h"

ComboBoxModel::ComboBoxModel(QList<QString> contents, QObject *parent) :
    QAbstractListModel(parent)
{
    QHash<int, QByteArray> roles;
    roles[ContentRole] = "content";
    roles[NumberRole] = "number";
    setRoleNames(roles);

    setContents(contents);
}

int ComboBoxModel::rowCount(const QModelIndex &parent) const
{
    return _contents.count();
}

QVariant ComboBoxModel::data(const QModelIndex &index, int role) const
{
    if (index.row() < 0 || index.row() > _contents.count())
        return QVariant();

    QString item = _contents[index.row()];
    if (role == ContentRole)
        return item;
    if (role == NumberRole)
        return index.row();
    return QVariant();
}

QString ComboBoxModel::selectedItem()
{
    return _selectedItem;
}

int ComboBoxModel::selectedIndex()
{
    return _selectedIndex;
}

void ComboBoxModel::setSelectedItem(QString item)
{
    _selectedItem = item;
}

void ComboBoxModel::setSelectedIndex(int index)
{
    _selectedIndex = index;
}

void ComboBoxModel::setContents(QList<QString> contents)
{
    foreach (QString item, contents)
    {
        addItem(item);
    }
}

void ComboBoxModel::addItem(QString item)
{
    beginInsertRows(QModelIndex(), rowCount(), rowCount());
    _contents << item;
    endInsertRows();
}
