/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/

/*!
    \file ConfigGenerator.h
    \brief Generating default config files, css stylesheet etc

    \author Bartosz Szatkowski <bulislaw@linux.com>
*/

#ifndef CONFIGGENERATOR_H
#define CONFIGGENERATOR_H

#include <QFile>
#include <QString>
#include <QDebug>

/*!
    ConfigGenerator generates configuration files (with default values),
    if a given file doesn't exist.
*/
class ConfigGenerator {

public:
    /*!
        Generates default css stylesheet for xslt transformations
        \param file file to be generated
        \return if file was generated - returns true; if file alredy exists
        returns true; if file doesn't exist but cannot be generated returns false
    */
    bool generateCss(QString file);

    /*! Generates default configuration files
        \param file file to be generated
        \return if file was generated - returns true; if file already exists
        returns true; if file doesn't exist but cannot be generated returns false
    */
    bool generateDefaultConfig(QString file);

private:
    bool generateFile(QString source, QString file);
};

#endif // CONFIGGENERATOR_H
