/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/

/*! \file DictTypeModel.cpp
    \brief Contains plugins data for qml UI

    \author Marcin Kaźmierczak <marcin.kazmierczak@comarch.pl>
*/

#include "DictTypeModel.h"

DictTypeModel::DictTypeModel(QList<CommonDictInterface *> plugins, QObject *parent) :
    QAbstractListModel(parent)
{
    QHash<int, QByteArray> roles;
    roles[TypeRole] = "type";
    roles[NumberRole] = "number";
    setRoleNames(roles);

    setDictTypes(plugins);
}

int DictTypeModel::rowCount(const QModelIndex &parent) const
{
    return _plugins.count();
}

void DictTypeModel::setDictTypes(QList<CommonDictInterface *> plugins)
{
    for(int i = 0; i < plugins.count(); i++)
    {
        addType(plugins[i]);
    }
}

QVariant DictTypeModel::data(const QModelIndex & index, int role) const
{
    if (index.row() < 0 || index.row() > _plugins.count())
        return QVariant();

    const CommonDictInterface* plugin = _plugins[index.row()];
    if (role == TypeRole)
        return plugin->type();
    if (role == NumberRole)
        return index.row();
    return QVariant();
}

void DictTypeModel::addType(CommonDictInterface *plugin)
{
    beginInsertRows(QModelIndex(), rowCount(), rowCount());
    _plugins << plugin;
    endInsertRows();
}
