/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/

/*! \file DictTypeSelectDialog.cpp
    \brief Implements plugin selection dialog

    \author Mateusz Półrola <mateusz.polrola@comarch.pl>
*/

#include "DictTypeSelectDialog.h"

DictTypeSelectDialog::DictTypeSelectDialog(QList<CommonDictInterface *> plugins, QWidget *parent) :
    QDialog(parent), model(plugins, this) {

    setWindowTitle(tr("Select dictionary type"));

    this->plugins = plugins;

    verticalLayout = new QVBoxLayout(this);
    setLayout(verticalLayout);

#ifndef Q_WS_MAEMO_5
    qmlView = new QDeclarativeView(this);

    ctxt = qmlView->rootContext();
    ctxt->setContextProperty("dictTypeModel", &model);

    qmlView->setSource(QUrl::fromLocalFile("/usr/share/mdictionary/qml/DictTypeSelectDialog.qml"));

    _selectedPlugin = 0;

    QGraphicsObject *rootObject = qmlView->rootObject();
    connect(rootObject, SIGNAL(selectedRow(int)),
            this, SLOT(pluginSelected(int)));

    qmlView->setResizeMode(QDeclarativeView::SizeRootObjectToView);
    verticalLayout->addWidget(qmlView);

#endif
#ifdef Q_WS_MAEMO_5

    pluginsListWidget = new QListWidget(this);

    verticalLayout->addWidget(pluginsListWidget);

    for(int i=0; i<plugins.count(); i++) {
        QListWidgetItem* item = new QListWidgetItem(plugins[i]->type());
        item->setData(PLUGIN_ROW_ROLE, i);
        pluginsListWidget->addItem(item);
    }

    _selectedPlugin = 0;

    connect(pluginsListWidget, SIGNAL(itemActivated(QListWidgetItem*)),
            this, SLOT(pluginSelected(QListWidgetItem*)));
#endif
}

void DictTypeSelectDialog::pluginSelected(QListWidgetItem *item) {
    _selectedPlugin = plugins[item->data(PLUGIN_ROW_ROLE).toInt()];
    accept();
}

void DictTypeSelectDialog::pluginSelected(int item) {
    _selectedPlugin = plugins[item];
    accept();
}

CommonDictInterface* DictTypeSelectDialog::selectedPlugin() {
    return _selectedPlugin;
}

CommonDictInterface* DictTypeSelectDialog::addNewDict(
        QList<CommonDictInterface *> plugins,
        QWidget *parent) {
    DictTypeSelectDialog dictSelect(plugins, parent);

    if(dictSelect.exec() == QDialog::Accepted) {
        return dictSelect.selectedPlugin();
    }
    else {
        return 0;
    }
}
