/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/
/*! \file DictTypeSelectDialog.h
    \brief Implements plugin selection dialog

    \author Mateusz Półrola <mateusz.polrola@comarch.pl>
*/

#ifndef DICTTYPESELECTDIALOG_H
#define DICTTYPESELECTDIALOG_H

#include <QDialog>
#include <QtGui>
#include "../../include/settings.h"
#include "../../include/CommonDictInterface.h"
#include "DictTypeModel.h"
#include <QtDeclarative/QDeclarativeView>
#include <QtDeclarative/QDeclarativeContext>

#define PLUGIN_ROW_ROLE 99      //TODO remove this


/*!
  Shows a list of loaded dictionaries plugins.
  Static function addNewdict will return selected plugin.
*/
class DictTypeSelectDialog : public QDialog {
    Q_OBJECT
public:    
    //! Shows dialog with a list of plugins
    /*!
      \param plugins list of loaded plugins
      \param parent parent widget
      \return selected plugin, if user cancels dialog it returns 0 (NULL)
      */
    static CommonDictInterface* addNewDict(
            QList<CommonDictInterface* > plugins,
            QWidget *parent = 0);

    //! \returns plugin selected by user
    CommonDictInterface* selectedPlugin();

protected:
    explicit DictTypeSelectDialog(QList<CommonDictInterface* > plugins,
                                  QWidget *parent = 0);
private Q_SLOTS:
    void pluginSelected(QListWidgetItem* item);
    void pluginSelected(int item);

private:
    QListWidget* pluginsListWidget;
    QList<CommonDictInterface*> plugins;
    QVBoxLayout* verticalLayout;
    CommonDictInterface* _selectedPlugin;

    QDeclarativeView* qmlView;
    QDeclarativeContext* ctxt;
    DictTypeModel model;
};

#endif // DICTTYPESELECTDIALOG_H
