/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/
/*! \file HistoryListDialog.h
    \brief Implements history list dialog

    \author Mateusz Półrola <mateusz.polrola@comarch.pl>
*/

#ifndef HISTORYLISTDIALOG_H
#define HISTORYLISTDIALOG_H

#include <QtGui>
#include <QDialog>
#include <QDeclarativeView>
#include <QDeclarativeContext>

#include "SearchBarWidget.h"
#include "../../include/History.h"
#include "HistoryListModel.h"


/*!
  Shows a history list and allows user to select one word of it.
  On desktop it is shown as a popup.
*/
class HistoryListDialog : public QDialog
{
    Q_OBJECT
public:
    //! Constructor
    /*!
      \param words list of history words
      \param parent parent widget
    */
    explicit HistoryListDialog(QStringList words, QWidget* parent = 0);

    //! \returns word selected by user
    QString selectedWord();

    //! \returns row number of selected word
    int selectedRow();

public Q_SLOTS:
    int exec();

private Q_SLOTS:
    void itemClicked(QModelIndex);
    void itemClicked(int);

private:
    QDeclarativeView *view;
    QVBoxLayout* mainLayout;

    QListWidget* historyListWidget;
    QVBoxLayout* verticalLayout;
    QString _selectedWord;
    int _selectedRow;
    QStringList oryginalList;

};

#endif // HISTORYLISTDIALOG_H
