/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/

/*! \file MenuWidget.cpp
    \brief Displays custom menu with tab widget containing all submenus.

    \author Mateusz Półrola <mateusz.polrola@comarch.pl>
*/

#include "MenuWidget.h"
#include <QDebug>
#include <QtGui>

MenuWidget::MenuWidget(QWidget *parent) :
    QWidgetAction(parent) {

    //creates custom tab widget, and sets style sheet to have centered tabs
    tabWidget = new MenuTabWidget();
    tabWidget->setStyleSheet("QTabWidget::tab-bar {alignment: center;}");

    applicationMenu = 0;

}

MenuWidget::~MenuWidget() {
    //because tabWidget has no parent we must destroy it
   delete tabWidget;
}

void MenuWidget::addSubMenu(QString title, QWidget *widget) {
    QScrollArea* sa = new QScrollArea(tabWidget);
    sa->setWidget(widget);
    sa->setWidgetResizable(true);
    sa->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    tabWidget->addTab(sa, title);
}


void MenuWidget::removeSubMenu(QString title) {
    for(int i = 0; i < tabWidget->count(); i++) {
        if(tabWidget->tabText(i) == title) {
            tabWidget->removeTab(i);
            break;
        }
    }
}

QWidget* MenuWidget::createWidget(QWidget *parent) {
    /*When we have request to create new widget we return tabWidget.
    When the menu is closing, tabWidget will receive hideEvent which will set
    its parent to 0 (NULL) and prevent it from delete, so we can still use this
    widget*/
    if(applicationMenu==0) {
        applicationMenu = parent;
        Q_EMIT setApplicationMenu(applicationMenu);
    }
    return tabWidget;
}


void MenuWidget::hideMenu() {
    tabWidget->parentWidget()->hide();
}


void MenuWidget::showMenu() {
    tabWidget->parentWidget()->show();
}
