/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/

/*! \file DictManagerWidget.h
    \brief Implements applications settings widget
    \author Mateusz Półrola <mateusz.polrola@comarch.pl>
*/

#ifndef SETTINGSWIDGET_H
#define SETTINGSWIDGET_H

#include <QWidget>
#include <QtGui>
#include <QPushButton>
#include <QDeclarativeView>
#include <QVariant>

#include "../../include/GUIInterface.h"
#include "../../include/settings.h"
#include "SpinBox.h"


/*!
  Shows settings that user can change.
  It allows to change limit of searches and limit of history.
  It also allows to select if application has to search in dictionaries or in
  bookmarks or in both of them. All changes are saved automatically after
  hiding of this widget.
  */
class SettingsWidget : public QDialog
{
    Q_OBJECT
public:
    //! Constructor
    /*!
      \param parent parent of this widget, which must be a subclass of
      GUIInterface, because it will use it to get current settings and
      set new ones.
      */
    explicit SettingsWidget(GUIInterface *parent = 0);

Q_SIGNALS:
    void setMinHistory(QVariant minValue);
    void setMaxHistory(QVariant minValue);
    void setValueHistory(QVariant value);
    void setMinSearchResult(QVariant minValue);
    void setMaxSearchResult(QVariant minValue);
    void setValueSearchResult(QVariant value);
    void setCheckedBookmarks(QVariant boolen);
    void setCheckedDictionaries(QVariant boolen);

    void notify(Notify::NotifyType, QString);

protected:
    void showEvent(QShowEvent *);
    void hideEvent(QHideEvent *);

private Q_SLOTS:
    void historySizeValueChanged(int value);
    void searchResulValueChanged(int value);
    void dictionariesCheckBoxChanged(bool boolean);
    void bookmarksCheckBoxChanged(bool boolean);

    void changed();
    #ifndef Q_WS_MAEMO_5
        void save();
    #endif
    #ifdef Q_WS_MAEMO_5
        void showSearchResultSizeInfo();
        void showHistorySizeInfo();
    #endif

private:
    void initalizeUI();

    QVBoxLayout* mainLayout;
    QDeclarativeView *view;

    SpinBox* historySizeSpinBox;
    SpinBox* searchResultSizeSpinBox;
    QVBoxLayout* verticalLayout;
    QFormLayout* spinBoxesFormLayout;
    QHBoxLayout* historySizeLayout;
    QHBoxLayout* searchResultLayout;

    #ifdef Q_WS_MAEMO_5
        QToolButton* historySizeInfoToolButton;
        QToolButton* searchResultSizeInfoToolButton;
    #endif

    QLabel* checkBoxesLabel;
    QCheckBox* searchInDictionariesCheckBox;
    QCheckBox* searchInBookmarksCheckBox;


    GUIInterface* guiInterface;
    Settings* settings;
    bool _changed;

    QString searchResultSizeToolTip;
    QString historySizeToolTip;

    #ifndef Q_WS_MAEMO_5
        QPushButton* closeButton;
        QHBoxLayout* footerLayout;
        bool _save;
    #endif
    int historyValue;
    int searchResultValue;
    bool dictionariesCheckBox;
    bool bookmarksCheckBox;
};

#endif // SETTINGSWIDGET_H
