/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/
/*!
    \file XdxfCachingDialog.cpp
    \brief Shows dialog with progress of dictionary caching

    \author Mateusz Półrola
*/

#include "XdxfCachingDialog.h"
#include "xdxfplugin.h"
#include <QDebug>


XdxfCachingDialog::XdxfCachingDialog(QWidget *parent): QDialog(parent) {
    verticalLayout = new QVBoxLayout(this);
    setLayout(verticalLayout);

    setWindowTitle(tr("Caching dictionary, please wait"));
    cachingProgressBar = new QProgressBar(this);
    cachingProgressBar->setMinimum(0);
    cachingProgressBar->setMaximum(100);
    cachingProgressBar->setTextVisible(true);

    cancelButton = new QPushButton(tr("Cancel"),this);
    cachingTimeLabel = new QLabel(this);
    cachingTimeLabel->hide();

    #ifndef Q_WS_MAEMO_5
            cachingLabel = new QLabel(this);
            cachingLabel->setText(tr("Caching dictionary, please wait"));
            verticalLayout->addWidget(cachingLabel, 0, Qt::AlignCenter);
    #endif

    verticalLayout->addWidget(cachingTimeLabel);
    verticalLayout->addWidget(cachingProgressBar);
    verticalLayout->addWidget(cancelButton);

    connect(cancelButton, SIGNAL(clicked()),
            this, SIGNAL(cancelCaching()));

    time.start();
    setModal(true);
}


void XdxfCachingDialog::updateCachingProgress(int progress, int time) {
    cachingProgressBar->setValue(progress);

    if(!cachingTimeLabel->isVisible())
        cachingTimeLabel->show();

    int seconds = float((100 - progress)*time) / (5*1000);

    cachingTimeLabel->setText(tr("Estimated time left: ") +
                          tr("%n second(s)", "", seconds));
    if(progress >= 100)
        this->accept();
}
