/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/
/*!
    \file XdxfDictSelectDialog.cpp
    \brief Shows dialog with list of dictionaries allowing user
  to select one of them.

    \author Mateusz Półrola <mateusz.polrola@comarch.com>
*/

#include "XdxfDictSelectDialog.h"

XdxfDictSelectDialog::XdxfDictSelectDialog(QList<DownloadDict> dicts,
                                           QWidget *parent) :
                    QDialog(parent) {


    setWindowTitle(tr("Select dictionary"));

    //here removing already added dictionary
    for (int i = 0; i < dicts.size(); i++){
        if(QFile::exists(QDir::homePath() + "/.mdictionary/" + dicts[i].title() + ".xdxf")){
            dicts.removeAt(i);
            i--;
        }
    }

#ifndef Q_WS_MAEMO_5
    model2 = new DictsListModel(dicts, this);
    proxyModel2 = new DictsProxyListModel;
    proxyModel2->setSourceModel(model2);
    proxyModel2->setTo("Polish");
    view= new QDeclarativeView();
    QDeclarativeContext* ctxt=view->rootContext();
    ctxt->setContextProperty("dictModel", proxyModel2);
    view->setSource(QUrl::fromLocalFile("/usr/share/mdictionary/qml/TableWidget.qml"));
    view->setResizeMode(QDeclarativeView::SizeRootObjectToView);
    view->setAlignment(Qt::AlignCenter);

    mainLayout = new QVBoxLayout;
    mainLayout->addWidget(view);
    this->setLayout(mainLayout);
    proxyModel2->setTo("English");

    QGraphicsObject *rootObject = view->rootObject();

    connect(rootObject,SIGNAL(dictLink(QString)),
            this,SLOT(itemClicked(QString)));
#else

    layout = new QVBoxLayout;
    setLayout(layout);

    checkBoxLayout = new QHBoxLayout;
    layout->addLayout(checkBoxLayout);

    langFrom = new QComboBox;
    langTo = new QComboBox;

    langFrom->setInsertPolicy(QComboBox::InsertAlphabetically);
    langTo->setInsertPolicy(QComboBox::InsertAlphabetically);

    langFromLabel = new QLabel(tr("From "));
    langToLabel = new QLabel(tr("To "));

    checkBoxLayout->addWidget(langFromLabel);
    checkBoxLayout->addWidget(langFrom, 10);
    checkBoxLayout->addWidget(langToLabel);
    checkBoxLayout->addWidget(langTo, 10);

    model = new DictsModel(dicts, this);

    proxyModel = new DictsProxyModel;
    proxyModel->setDynamicSortFilter(true);
    proxyModel->setSourceModel(model);

    treeView = new QTreeView;
    treeView->setModel(proxyModel);
    treeView->setRootIsDecorated(false);
    treeView->setExpandsOnDoubleClick(false);

    treeView->setSortingEnabled(true);
    treeView->sortByColumn(0, Qt::AscendingOrder);

    treeView->setWordWrap(true);

    #ifndef Q_WS_MAEMO_5
        treeView->resizeColumnToContents(0);
        treeView->resizeColumnToContents(1);
        treeView->setColumnWidth(2, 300);
        treeView->resizeColumnToContents(3);
    #else
        treeView->setColumnWidth(0, 150);
        treeView->setColumnWidth(1, 150);
        treeView->setColumnWidth(2, 300);
        treeView->setColumnWidth(3, 150);
    #endif

    layout->addWidget(treeView);

    connect(langFrom, SIGNAL(currentIndexChanged(int)),
            this, SLOT(refreshDictList()));

    connect(langTo, SIGNAL(currentIndexChanged(int)),
            this, SLOT(refreshDictList()));

    connect(treeView, SIGNAL(activated(QModelIndex)),
            this, SLOT(itemClicked(QModelIndex)));

    #ifndef Q_WS_MAEMO_5
        setMinimumSize(800,500);
    #else
        setMinimumHeight(350);
    #endif

    initializeDicts();
    #endif
}


void XdxfDictSelectDialog::initializeDicts() {
    //scan of all languages of dictionaries, using QSet to get only distinct languages
    QSet<QString> languagesFrom;
    QSet<QString> languagesTo;

    for(int i=0; i < model->rowCount(QModelIndex()); i++) {
        languagesFrom.insert(
                model->data(model->index(i, 0, QModelIndex())).toString());
        languagesTo.insert(
                model->data(model->index(i, 1, QModelIndex())).toString());
    }

    //removes one dictionary which from and to languages are empty....
    //bug in site with dictionaries
    languagesFrom.remove(QString());
    languagesTo.remove(QString());

    //sorting of found languages
    QList<QString> langFromList = languagesFrom.toList();
    qSort(langFromList);

    QList<QString> langToList = languagesTo.toList();
    qSort(langToList);

    //and adding them to combobox, first item in each combobox is "Any"
    langFrom->addItem(tr("Any"));
    for(int i=0; i < langFromList.count(); i++) {
         langFrom->addItem(langFromList.at(i));
    }

    langTo->addItem(tr("Any"));
    for(int i=0; i < langToList.count(); i++) {
         langTo->addItem(langToList.at(i));
    }
}


void XdxfDictSelectDialog::refreshDictList() {
#ifndef Q_WS_MAEMO_5


#else

    //if selected language is "Any"(index 0), from filter string is set to empty string, proxy model uses empty string as special case and don't filter by this field.
    if(langTo->currentIndex() == 0)
        proxyModel->setTo(QString());
    else
        proxyModel->setTo(langTo->currentText());

    if(langFrom->currentIndex() == 0)
        proxyModel->setFrom(QString());
    else
        proxyModel->setFrom(langFrom->currentText());

#endif
}


void XdxfDictSelectDialog::itemClicked(QString link) {
#ifndef Q_WS_MAEMO_5
    _link = link;
    accept();
#endif
}

void XdxfDictSelectDialog::itemClicked(QModelIndex index) {
#ifdef Q_WS_MAEMO_5
    _link = index.model()->data(index, Qt::UserRole).toString();
    accept();
#endif
}
