/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/
/*!
    \file XdxfDictSelectDialog.h
    \brief Shows dialog with list of dictionaries allowing user
  to select one of them.

    \author Mateusz Półrola <mateusz.polrola@comarch.com>
 */

#ifndef XDXFDICTSELECTDIALOG_H
#define XDXFDICTSELECTDIALOG_H

#include <QDialog>
#include <QtGui>
#include <QFile>
#include <QDir>
#include <QDeclarativeView>
#include <QDeclarativeContext>

#include "DownloadDict.h"
#include "DictsListModel.h"
#include "DictsModel.h"
#include "DictsProxyModel.h"
#include "DictsProxyListModel.h"


/*!
  Shows dialog with list of dictionaries and informations about them,
  allowing user to filter data based on dictionaries languages,
  and to select one of them.
*/
class XdxfDictSelectDialog : public QDialog {
    Q_OBJECT
public:
    /*!
        Constructor
        \param dicts list of DownloadDict objects describing dictionaries.
    */
    XdxfDictSelectDialog(QList<DownloadDict> dicts,
                                  QWidget *parent = 0);

    /*!
        Returns download link of dictionary selected by user. This string is set
        only when user select any dictionary (dialog was accepted), otherwise it
        is empty.
    */
    QString link() { return _link;}

private Q_SLOTS:
    //! creates items for comboboxes and creates model with dicts info
    void initializeDicts();

    //! filters dicts after filtering settings change
    void refreshDictList();

    //! accept dialog and sets download link of clicked dictionary
    void itemClicked(QModelIndex);

    void itemClicked(QString link);

private:
    QVBoxLayout* mainLayout;
    QDeclarativeView *view;
    DictsListModel* model2;
    DictsProxyListModel *proxyModel2;

    QTreeView* treeView;
    DictsModel* model;
    DictsProxyModel *proxyModel; //used by treeView to allow filtering and sorti
    QVBoxLayout* layout;
    QHBoxLayout* checkBoxLayout;
    QComboBox* langFrom;
    QComboBox* langTo;
    QLabel* langFromLabel;
    QLabel* langToLabel;
    QList<DownloadDict>* dictList;
    QString _link;
};

#endif // XDXFDICTSELECTDIALOG_H
